@@ -215,6 +215,10 @@ class Dialcentral(object):
 				self._alarmHandler = alarm_handler.AlarmHandler()
 			except ImportError:
 				alarm_handler = None
+			except Exception:
+				with gtk_toolbox.gtk_lock():
+					self._errorDisplay.push_exception()
+				alarm_handler = None
 			if hildon is not None:
 				import led_handler
 				self._ledHandler = led_handler.LedHandler()
@@ -798,13 +802,13 @@ def run_doctest():
 
 def run_dialpad():
 	_lock_file = os.path.join(constants._data_path_, ".lock")
-	with gtk_toolbox.flock(_lock_file, 0):
-		gtk.gdk.threads_init()
+	#with gtk_toolbox.flock(_lock_file, 0):
+	gtk.gdk.threads_init()
 
-		if hildon is not None:
-			gtk.set_application_name(constants.__pretty_app_name__)
-		handle = Dialcentral()
-		gtk.main()
+	if hildon is not None:
+		gtk.set_application_name(constants.__pretty_app_name__)
+	handle = Dialcentral()
+	gtk.main()
 
 
 class DummyOptions(object):
